import pandas as pd
import bs4
from typing import List

def convert(file_path: str) -> pd.DataFrame:
  """
    Parameters:
      file_path: path to excel sheet
  """
  df = pd.read_excel(file_path)
  return df

def transform_name_to_slug(raw_ticker: str):
  """
    Parameters: 
      raw_ticker: cse ticker to be converted to slug
  """
  transformed = raw_ticker.lower().replace(".","").replace(' ', '-')
  return transformed

def parse_description_tags(description_tags: List[bs4.element.Tag])-> str:
  """
    Parameters:
      description_tags: html tags from webpage, usually p tag containing description
    Returns:
      description: description for ticker
  """
  if len(description_tags) > 0:
    description_tag = description_tags[0]
    # grab contents from desscription tag
    if len(description_tag.contents) == 0:
      return ''
    else:
      return description_tag.contents[0]
  # company does not have profile
  else: 
    return '' 

def make_cse_path(raw_ticker: str, raw_industry: str)-> str:
  """makes slug for ticker for the cse
  
    Parameters:
      raw_ticker: cse ticker from xlsx sheet
      raw_industry: verbatim industry from ticker, not slugified
    Returns:
      description: url for cse files for download
  """
  if pd.isna(raw_industry):
    return ''
  # verify raw_industry is in industry
  cse_industries = ['Industry', 'Mining', 'Diversified Industries',
      'Life Sciences', 'Oil and Gas', 'Technology', 'CleanTech']
  # do later
  base_cse_url = 'https://thecse.com/en/listings'
  industry = raw_industry.lower().replace(' ', '-')
  ticker = transform_name_to_slug(raw_ticker)
  url = f'{base_cse_url}/{industry}/{ticker}'
  return url



import requests
import pandas as pd
import multiprocessing as mp
from concurrent.futures import ThreadPoolExecutor
from json import loads
from bs4 import BeautifulSoup

# importing the sys module 
import sys 
  
# the setrecursionlimit function is 
# used to modify the default recursion 
# limit set by python. Using this,  
# we can increase the recursion limit 
# to satisfy our needs 

sys.setrecursionlimit(10**6) 


def get_description_for_ticker(ticker: str)-> str: # change the body of the loop to function
  """
    set of functionality
  """
  # grab ticker return desc
  # do on google colab
  # https://stackoverflow.com/questions/56987872/parallelize-pandas-column-update
  symbol = grab_symbol_for_ticker(ticker)
  if symbol is None:
    return ''
  return company_description_by_ticker(symbol)

def get_mig_report(filename: str='', exchange: str="TSX", return_df: bool =False) -> str:
  """
  Description:
    Gets excel spreadsheet from tsx api programatically.
    See for more flexibility :func:`dl_tsx_xlsx <cad_tickers.exchanges.tsx.dl_tsx_xlsx>`

  Parameters:
    filename: Name of the file to be saved
    exchanges: TSX, TSXV
    return_df: Return a pandas dataframe

  Returns:
    filePath: returns path to file or dataframe

  See ://stackoverflow.com/questions/13567507/passing-csrftoken-with-python-requests

  """
  tsx_url = 'https://api.tmxmoney.com/en/migreport/search'
  client = requests.session()
  # Retrieve the CSRF token first
  client.get(tsx_url)  # sets cookie
  if 'csrftoken' in client.cookies:
      # Django 1.6 and up
      csrftoken = client.cookies['csrftoken']
  else:
      # older versions
      csrftoken = client.cookies['csrf']
  login_data = dict(report_type='excel', csrfmiddlewaretoken=csrftoken)
  if exchange in ["TSX", "TSXV"]:
    login_data["exchanges"] = exchange

  r = client.post("https://api.tmxmoney.com/en/migreport/search", data=login_data, headers=dict(Referer=tsx_url))
  resp_data = r.content
  if return_df is True:
    return pd.read_excel(resp_data)
  else:
    resp_headers = r.headers
    if "text/html" in resp_headers["Content-Type"]:
      return None
    elif resp_headers["Content-Type"] == "application/ms-excel":
      print(f"Downloaded data from {tsx_url} for {exchange} to {filename}")
      with open(filename, 'wb') as s:
        s.write(resp_data)
      return filename
    else:
      return None

def grab_symbol_for_ticker(ticker: str) -> str:
  """
  Description:
    Grabs the first symbol from ticker data
    all symbols should lead to valid webpages for data scrapping.

  Parameters: 
    ticker: string representing the stock ticker

  Returns: 
    symbol: string - searchable string in the quotemedia api or empty string
  """

  if ticker is None or ticker is '':
    return ''

  ticker_data = lookup_symbol_by_ticker(ticker)
  if len(ticker_data) == 0:
    # splice name and try again
    # remove everything past dot
    clean_ticker = ticker.split(".", 1)[0]
    ticker_data = lookup_symbol_by_ticker(clean_ticker)
    
    # Ticker likely has no data
    # see NTY
    if len(ticker_data) == 0:
      return ''
  return ticker_data[0].get('symbol')


def add_descriptions_to_df_pp(df: pd.DataFrame, max_workers: int = 16) -> pd.DataFrame:
  """
  Description: fetch descriptions for tickers in parallel
  noticable speedup uses thread pool which should be faster

  Input:
    df: dataframe containing tickers
  Returns:
    df: updated dataframe with a descriptions if available
  """
  df['description'] = ''
  tickers = df['Ticker'].tolist()
  with ThreadPoolExecutor(max_workers=max_workers) as tpe:
    iterables = tpe.map(get_description_for_ticker, tickers)
    descriptions = list(iterables)
  df['description'] = descriptions
  return df

def add_descriptions_to_df_pp_legacy(df: pd.DataFrame) -> pd.DataFrame:
  """
  Description: fetch descriptions for tickers in parallel
  noticable speedup, keeping this to verify speed increase

  Input:
    df: dataframe containing tickers
  Returns:
    df: updated dataframe with a descriptions if available
  """
  df['description'] = ''
  tickers = df['Ticker'].tolist()
  with mp.Pool() as p:
    descriptions = p.map(get_description_for_ticker, tickers)
  df['description'] = descriptions
  return df

# https://stackoverflow.com/questions/56987872/parallelize-pandas-column-update
def add_descriptions_to_df(df) -> pd.DataFrame:
  """
  Description: single process solution to fetching descriptions

  Input:
    df: dataframe containing tickers
  Returns:
    df: updated dataframe with a descriptions if available
  """
  df['description'] = ''
  for index, row in df.iterrows():
    ticker = df.at[index, 'Ticker']
    # grab ticker return desc
    # do on google colab
    # https://stackoverflow.com/questions/56987872/parallelize-pandas-column-update
    symbol = grab_symbol_for_ticker(ticker)
    if symbol is None:
      pass
    description = company_description_by_ticker(symbol)
    df.at[index,'description'] = description
  return df

def company_description_by_ticker(ticker)-> str:
  """
  
  Description: Grabs searchable ticker from quotemedia using tmx ticker

  Input:
    ticker: string 
  Returns:
    df:  updated dataframe with a descriptions if available
  """
  # get lookup symbol
  search_symbol = grab_symbol_for_ticker(ticker)
  if search_symbol is '':
    return ''
  params = {'qm_symbol': search_symbol}
  # // //*[@id="pane-news"]/div/div/div[1]/div/div[1]/div[2]/section[1]/p

  search_url = f'https://web.tmxmoney.com/company.php'
  r = requests.get(search_url, params=params)
  html_content = r.text
  # Parse the html content
  soup = BeautifulSoup(html_content, "lxml")
  # selector copied from chrome https://money.tmx.com/en/quote/ZMD.H
  description_selector = '#pane-news > div > div > div.col-md-9 > div > div:nth-child(1) > div.tmx-panel-body.pt-0 > section:nth-child(1) > p'
  description_tags = soup.select(description_selector)
  if len(description_tags) > 0:
    description_tag = description_tags[0]
    # grab contents from desscription tag
    if len(description_tag.contents) == 0:
      return ''
    else:
      return description_tag.contents[0]
  # company does not have profile
  else: 
    return ''

def lookup_symbol_by_ticker(ticker: str)-> list:
  """
  
  Description: Returns search array dictionary for tickers
  
  .. note::

    sometimes the name of the ticker in the xlsx 
    sheet is off slightly and we need to find the "real ticker".
    Uses standard api (not graphql) to grab tickers

    Example searchpoint is https://app.quotemedia.com/lookup?callback=tmxtickers&q=zmd&limit=5&webmasterId=101020

  See `Tmx Graphql <https://app-money.tmx.com/graphql>`_  and the new `tmx site <https://money.tmx.com/en/>`_

  Input:
    ticker: tmx ticker

  Output:
    quote_data: list of ticker metadata
  """
  if ticker is None:
    return []
  callback = 'tmxtickers'
  # Theses values can be hardcoded
  params = {
    'callback': callback,
    'limit': 5,
    'webmasterId': 101020,
    'q': ticker
  }
  quote_lookup_url = 'https://app.quotemedia.com/lookup'
  r = requests.get(quote_lookup_url, params=params)
  quote_data = r.text

  if quote_data is None:
     raise Exception('No data returned, check if api is depreciated or contact author for help.')
  s_idx = quote_data.find('(')
  e_idx = quote_data.rfind(')')

  if quote_data == f"{callback}();":
    return []
  # All symbols returned all valid
  try:
    data = loads(quote_data[s_idx + 1:e_idx])
    return data
  except Exception as e:
    print(ticker)
    print('fail to run')
    print(e)
    exit(1)

def dl_tsx_xlsx(filename: str = '', **kwargs) -> str:
  """
  Description: Gets excel spreadsheet from the tsx api using programatically

  .. note::

    Replicates api calls in TSX discover tool with all parameters.
    See `migreport search <https://api.tmxmoney.com/en/migreport/search>`_
    Note that not all parameters are documented and/or limited validation

  Parameters:
    filename: Name of the file to be saved

  Kwargs:
    * exchanges (string): TSX, TSXV
    * marketcap (string): values from 0 to specified value
    * sectors (string): cpc, clean-technology, closed-end-funds, technology

  Returns:
    data - returns path to file or pandas dataframe

    pd.DataFrame 
    
    ===========   =====================================================================
    Ex.           Exchange ticker in TSXV, TSX 
    Name          Full name of ticker 
    Ticker        Symbol usually 4 characters or less
    QMV($)        Quoted Market Value, I assume this is based on the "currency".
    HQ Region     Headquarters region usually a country (need to double check)
    HQ Location   Usually a province or state
    Sector        Main sector, technology
    Sub Sector    Sub Sector
    ===========   =====================================================================

  .. note
     if this package gets popular enough, I will add more documentation

  See `passing csrftoken <https://stackoverflow.com/questions/13567507/passing-csrftoken-with-python-requests>`_
  """

  tsx_url = 'https://api.tmxmoney.com/en/migreport/search'
  client = requests.session()
  # Retrieve the CSRF token first
  client.get(tsx_url)  # sets cookie
  if 'csrftoken' in client.cookies:
      # Django 1.6 and up
      csrftoken = client.cookies['csrftoken']
  else:
      # older versions
      csrftoken = client.cookies['csrf']
  search_data = dict(report_type='excel', csrfmiddlewaretoken=csrftoken)

  for k, v in kwargs.items():
    if k == 'exchanges':
      if k in ["TSX", "TSXV"]:
        search_data["exchanges"] = k
    elif k == 'marketcap':
      if k in ["0-50", "50-250", "250-500", "500-1000", '1000-9999999999999999999999']:
        search_data["marketcap"] = k
    else:
      search_data[k] = v

  r = client.post(tsx_url, data=search_data, headers=dict(Referer=tsx_url))
  resp_headers = r.headers
  if "text/html" in resp_headers["Content-Type"]:
    return None
  elif resp_headers["Content-Type"] == "application/ms-excel":
    resp_data = r.content
    if filename is '':
      return pd.read_excel(resp_data)
    else:
      with open(filename, 'wb') as f_:
        f_.write(resp_data)
      return filename
  else:
    return None

# Add endpoint to query search parameters for tsx spreadsheets
if __name__ == "__main__":
  from datetime import datetime
  start_time = datetime.now()
  import argparse
  parser = argparse.ArgumentParser()
  parser.add_argument("-f", 
                        "--file", 
                        help="file name (default: %(default)s)'", 
                        default="tsx.xlsx") 
  parser.add_argument('-e',
                    "--exchange",
                    default='TSX',
                    const='TSX',
                    nargs='?',
                    choices=('TSX', 'TSXV', 'None', 'All'),
                    help='TSX, TSXV, All (default: %(default)s)') 
  args = parser.parse_args()
  df = dl_tsx_xlsx(sectors='technology')
  df = add_descriptions_to_df_pp(df)
  print(df)
  end_time = datetime.now()
  print(end_time - start_time)



import requests
import re
import pandas as pd
from concurrent.futures import ThreadPoolExecutor
from bs4 import BeautifulSoup
from cad_tickers.util import parse_description_tags, make_cse_path

def get_cse_files(filename: str ='cse.xlsx', filetype: str ="xlsx") -> str:
  """Gets excel spreadsheet from api.tsx using requests

  Parameters:
    filename: Name of the file to be saved
    filetype: Save as pdf or xlsx

  Returns:
    filePath returns path to file

  See ://stackoverflow.com/questions/13567507/passing-csrftoken-with-python-requests

  """
  # TODO force it to be pdf or xlsx
  # https://www.thecse.com/export-listings/xlsx?f={}
  # https://www.thecse.com/export-listings/pdf?f={}
  URL = f'https://www.thecse.com/export-listings/{filetype}?f=' + r'{}'
  r = requests.get(URL)
  responseHeaders = r.headers
  if "text/html" in responseHeaders["Content-Type"]:
    return None
  elif any(re.findall(r'application/vnd.ms-excel|application/pdf|xlsx',
      responseHeaders["Content-Type"],
      re.IGNORECASE)
    ):
    respData = r.content
    filepath = f'{filename}'
    with open(filepath, 'wb') as s:
      s.write(respData)
    return filepath
  else:
    return None

def clean_cse_data(raw_df: pd.DataFrame)-> pd.DataFrame:
  """Removes bad data from cse dataframe.

  Parameters:
    raw_df
      Dataframe with mostly unnamed columns from pandas df import

      =============  ====================================================================
      CSE Listings   Label for Company data
      Unnamed: 1     Listing symbol from the cse exchange needs a mapper to yahoo finance
      Unnamed: 2     Enum of industry including Mining
      Unnamed: 3     Enum such as CSE Composite
      Unnamed: 4     Enum such as CSE Composite 
      Unnamed: 5     Usually CAD
      Unnamed: 6     empty (pandas import error, dropped)
      Unnamed: 7     Date when trading started
      =============  ====================================================================

  Returns:
    clean_df
      Dataframe with bad data removed

      ==========  ====================================================================
      Company     Full name of the company  
      Symbol      Listing symbol from the cse exchange needs a mapper to yahoo finance
      Industry    Enum of industry including Mining
      Identifier  Broad category (US Cannabis)
      Indices     Enum such as CSE Composite
      Currency    Usually CAD
      Trading     Date when trading started
      urls        url to listing on cse website
      ==========  ====================================================================
  """
  # drop all nans
  df = raw_df
  df = df.dropna(axis=0, how='all')
  # drop empty column
  df = df.drop(df.columns[6], axis=1)
  # grab logically column names from first row
  column_labels = df.iloc[1, :].values.tolist()
  df.columns = column_labels
  # dropping title row and column titles row 
  df = df.drop([df.index[0], df.index[1]])
  df = df.reset_index(drop=True)
  return df

def get_cse_tickers_df()-> pd.DataFrame:
  """Grab cse dataframe from exported xlsx sheet

    Returns:
      clean_df
        Dataframe with with randomly selected values. Data columns are as follows:

        ==========  ====================================================================
        Company     Full name of the company  
        Symbol      Listing symbol from the cse exchange needs a mapper to yahoo finance
        Industry    Enum of industry including Mining
        Identifier  Broad category (US Cannabis)
        Indices     Enum such as CSE Composite
        Currency    Usually CAD
        Trading     Date when trading started
        urls        url to listing on cse website
        ==========  ====================================================================
  """
  URL = f'https://www.thecse.com/export-listings/xlsx?f=' + r'{}'
  r = requests.get(URL)
  responseHeaders = r.headers
  if "text/html" in responseHeaders["Content-Type"]:
    return None
  elif any(re.findall(r'application/vnd.ms-excel|application/pdf|xlsx',
      responseHeaders["Content-Type"],
      re.IGNORECASE)
    ):
    respData = r.content
    df = pd.read_excel(respData)
    clean_df = clean_cse_data(df)
    # add urls
    clean_df['urls'] = clean_df.apply(lambda x: make_cse_path(x['Company'], x['Industry']), axis=1)
    return clean_df
  else:
    return None

def get_description_for_url(url: str)-> str:
  """
    Parameters:
      url - link to ticker can be empty string
    Returns:
      description - details of what the ticker does, can be empty string
  """
  if url is '':
    return ''
  r = requests.get(url)
  html_content = r.text
  soup = BeautifulSoup(html_content, "lxml")
  description_selector = '#block-system-main div.company-description > p'
  description_tags = soup.select(description_selector)
  return parse_description_tags(description_tags)

def add_descriptions_to_df(df: pd.DataFrame, max_workers: int =16) -> pd.DataFrame:
  """
    Parameters:
      clean_df
        Dataframe with with randomly selected values. Data columns are as follows:

        ==========  ====================================================================
        Company     Full name of the company  
        Symbol      Listing symbol from the cse exchange needs a mapper to yahoo finance
        Industry    Enum of industry including Mining
        Identifier  Broad category (US Cannabis)
        Indices     Enum such as CSE Composite
        Currency    Usually CAD
        Trading     Date when trading started
        urls        url to listing on cse website
        ==========  ====================================================================

      max_workers
        maximum number of thread workers to have

    Returns:
      df 
        Dataframe descriptions in every column if valid

        ===========  ====================================================================
        Company      Full name of the company  
        Symbol       Listing symbol from the cse exchange needs a mapper to yahoo finance
        Industry     Enum of industry including Mining
        Identifier   Broad category (US Cannabis)
        Indices      Enum such as CSE Composite
        Currency     Usually CAD
        Trading      Date when trading started
        urls         url to listing on cse website
        description  cse description scrapped from website
        ===========  ====================================================================

  """
  urls = df['urls'].tolist()
  with ThreadPoolExecutor(max_workers=max_workers) as tpe:
    iterables = tpe.map(get_description_for_url, urls)
    descriptions = list(iterables)
  df['description'] = descriptions
  return df

if __name__ == "__main__":
  from datetime import datetime
  import argparse
  start_time = datetime.now()
  parser = argparse.ArgumentParser()
  parser.add_argument("-f", 
                        "--file", 
                        help="file name (default: %(default)s)'", 
                        default="cse.xlsx") 
  parser.add_argument('-t',
                    "--type",
                    default='xlsx',
                    const='xlsx',
                    nargs='?',
                    choices=('xlsx','pdf'),
                    help='xlsx or pdf (default: %(default)s)') 
  get_cse_files()
  # args = parser.parse_args()
  # cse_df = get_cse_tickers_df()
  # df = add_descriptions_to_df(cse_df)
  # end_time = datetime.now()
  # get_cse_files(args.file, args.type)
  # print(df)



import requests
import bs4
from typing import List, Union, Tuple

def scrap_news_for_ticker(ticker: str)-> List[dict]:
  """ Extracts webpage data from a ticker

    Parameters:
      ticker - yahoo finance ticker
    Returns:
      news_data - list of dicts extracted from webpage
        * source - str
        * link_href - link from post (can be relative or absolute)
        * link_text - description for link
        * ticker - reference to original ticker

  """
  yahoo_base_url = 'https://finance.yahoo.com'
  news_items = get_ynews_for_ticker(ticker, yahoo_base_url)
  news_data = []
  for news_item in news_items:
    # remove comments
    for comment in news_item(text=lambda text: isinstance(text, bs4.Comment)):
      comment.extract()
    # grab description header, stuff next too image
    news_content = news_item.find("div", {"class": "Ov(h) Pend(44px) Pstart(25px)"})
    if news_content is None:
      # try again with different class 
      news_content = news_item.find('div', {'class': 'Ov(h)'})
    source = find_news_source(news_content)
    link_href, link_text = find_news_link_and_text(news_content)
    news_data.append({
      "source": source,
      "link_href": link_href,
      "link_text": link_text,
      "ticker": ticker
    })
  return news_data

def get_ynews_for_ticker(ticker: str, yahoo_base_url='https://finance.yahoo.com')-> List[bs4.element.Tag]:
  """ Returns initial news items fetched from yahoo when loading quote page.
  Since yahoo has lazy loading, not all items are returned. Seems like ads are not loaded
  because of lazy loading.

    Parameters:
      ticker - yahoo formatted ticker str
      yahoo_base_url - optional parameter that is the base of the request

    Returns:
      news_items - list of key html content for the news item
  """
  yahoo_qurl = f'{yahoo_base_url}/quote/{ticker}?p={ticker}'
  r = requests.get(yahoo_qurl)
  html_content = r.text
  soup = bs4.BeautifulSoup(html_content, "lxml")
  news_items = soup.find_all("li", {"class": "js-stream-content Pos(r)"})  # This will return a list of all line items in the markup.
  return news_items

def find_news_link_and_text(news_content: bs4.element.Tag)-> Tuple[str, str]:
  """Finds news link from news_content. 
     Assumes comments are deleted from the yahoo finance news items

  Parameters: 
    news_content - html based data for the news article 

  Returns:
    link_href - link in html markup
    link_text - link text in html markup
  """
  if news_content is None: return '', ''
  link_tag = news_content.find("a")
  link_href = link_tag.get('href')
  link_text = link_tag.text
  return link_href, link_text

def find_news_source(news_content: bs4.element.Tag)-> Union[None, str]:
  """Utility function to verify news format from yahoo has not changed

    when grabbing data from yahoo with requests, it seems date is not returned.

    Parameters:
      news_content: html based data for the news article
    
    Returns:
      source - publisher of article

    wrapper div around content - such as - CNW Group 2 days ago
  """
  if news_content is None: return
  # wrapper div around content - such as - CNW Group 2 days ago
  wrapper_div = news_content.find("div", {"class": "C(#959595) Fz(11px) D(ib) Mb(6px)"})
  source = wrapper_div.text
  # content_spans = wrapper_div.find_all("span")
  # print(content_spans)
  # source, date = [content_span.text for content_span in content_spans]
  return source

if __name__ == '__main__':
  scrap_news_for_ticker("IP.CN")
  


import requests
import pandas as pd
from datetime import datetime

def get_halts_resumption()-> pd.DataFrame:
  """Gets the latest 25 halts from the iiroc

  Returns:
    halt_df
      Dataframe with bad data removed

      ==========  ====================================================================  
      Halts       Details of halts
      Listing     Extracted ticker from halt
      ==========  ====================================================================
  """
  now = datetime.now()
  year = now.year
  # get year
  iiroc_url = f'https://iiroc.mediaroom.com/index.php?year={year}'
  r = requests.get(iiroc_url)
  html_data = r.text
  halts_df = pd.read_html(html_data, attrs={'class': 'spintable'})
  halt_df = halts_df[0]
  halt_df.columns = ['Halts']
  halt_df["Listing"] = halt_df["Halts"].str.split().str[-1]
  halt_df = halt_df.drop(halt_df.tail(1).index)
  return halt_df
  # extract last word as
  # #wd_printable_content > div.wd_newsfeed_releases > div > table

if __name__ == '__main__':
  get_halts_resumption()
  


"""
Exchanges
----------

Downloading and cleaning data from the cse and tsx exchanges
"""

from cad_tickers.exchanges.cse import *
from cad_tickers.exchanges.tsx import *

# Example graphql endpoint data
# for the tsx output
# Ex: {"operationName":"findCompaniesByKeywords","variables":{"keywords":"zmd"},"query":"query findCompaniesByKeywords($keywords: String) {\n  findCompaniesByKeywords(keywords: $keywords) {\n    symbol\n    name\n    exchange\n    __typename\n  }\n}\n"}`


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['cad_tickers', 'cad_tickers.exchanges', 'cad_tickers.news', 'cad_tickers.util']

package_data = \
{'': ['*']}

install_requires = \
['beautifulsoup4>=4.9.1,<5.0.0',
 'coverage>=5.2,<6.0',
 'lxml>=4.5.2,<5.0.0',
 'pandas>=1.0.5,<2.0.0',
 'requests>=2.24.0,<3.0.0',
 'xlrd>=1.2.0,<2.0.0']

setup_kwargs = {
    'name': 'cad-tickers',
    'version': '0.2.7',
    'description': 'Various Stock Utilties Created by me',
    'long_description': "[![PyPI version](https://badge.fury.io/py/cad-tickers.svg)](https://badge.fury.io/py/cad-tickers) [![Downloads](https://pepy.tech/badge/cad-tickers)](https://pepy.tech/project/cad-tickers) [![Documentation Status](https://readthedocs.org/projects/cad-tickers/badge/?version=latest)](https://cad-tickers.readthedocs.io/en/latest/?badge=latest) [![codecov](https://codecov.io/gh/FriendlyUser/cad_tickers/branch/master/graph/badge.svg)](https://codecov.io/gh/FriendlyUser/cad_tickers)\n \n## Cad Tickers\n\nFor the tsx searching, it was kinda tedious to test each of the possible values, as a result, only `exchanges` and `marketcap` values are validated.\n\nGiven the new redesign of the web.tmxmoney site, don't expect the existing api to work\nfor a super long period of time.\n\nSupport will be provided to the best of my ability.\n\n### How to run tests\n\n```\npytest\n```\n\n### How to deploy\n\n\n```\n# Needed for readthedocs documentation\npoetry export -f requirements.txt > requirements.txt.\n```\n\n#### Todo\n\nAdd parameters and returns, double sync with readthe docs and github pages.\n\n- [ ] Go through list in https://thecse.com/en/listings and make pandas dataframe?\nIterate until last css is no longer present\n\n- [ ] make another function that uses the new graphql api instead of the standard api.\n- [x] Convert all the Input to Parameters and output to Return\n- [x] add just read the docs\n- [x] add code coverage uploading \n- [x] news and iiroc fetching\n",
    'author': 'David Li',
    'author_email': 'davidli012345@gmail.com',
    'maintainer': 'David Li',
    'maintainer_email': 'davidli012345@gmail.com',
    'url': 'https://github.com/FriendlyUser/cad_tickers',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6.1,<4.0.0',
}


setup(**setup_kwargs)
